@@ -41,7 +41,7 @@ class TransportLog(object):
             # and returns 'GET' and 'PATCH' respectively, so we do not need
             # the name of the HTTP method to be passed.
             method = func.__name__[3:].upper()
-            LOG.debug(u'%(type)s %(method)s: %(arguments)s',
+            LOG.debug('%(type)s %(method)s: %(arguments)s',
                       {'type': self.resource_type,
                        'method': method,
                        'arguments': jsonutils.dumps(kwargs)})
@@ -148,7 +148,7 @@ def caches(keygen, ttl, cond=None):
             else:
                 # NOTE(kgriffs): unpackb does not default to UTF-8,
                 # so we have to explicitly ask for it.
-                value = msgpack.unpackb(packed_value, encoding='utf-8')
+                value = msgpack.unpackb(packed_value)
 
             return value
 
@@ -203,7 +203,7 @@ def api_version_manager(version_info):
         @functools.wraps(fn)
         def register_api(driver, conf):
             if (deprecated and
-                    [api_version] not in conf.enable_deprecated_api_versions):
+                    api_version not in conf.enable_deprecated_api_versions):
                 return None
 
             if deprecated:
