@@ -45,16 +45,7 @@ def _connection(conf):
     if conf.uri and 'ssl=true' in conf.uri.lower():
         kwargs = {'connect': False}
 
-        # Default to CERT_REQUIRED
-        ssl_cert_reqs = ssl.CERT_REQUIRED
-
-        if conf.ssl_cert_reqs == 'CERT_OPTIONAL':
-            ssl_cert_reqs = ssl.CERT_OPTIONAL
-
-        if conf.ssl_cert_reqs == 'CERT_NONE':
-            ssl_cert_reqs = ssl.CERT_NONE
-
-        kwargs['ssl_cert_reqs'] = ssl_cert_reqs
+        kwargs['ssl_cert_reqs'] = getattr(ssl, conf.ssl_cert_reqs)
 
         if conf.ssl_keyfile:
             kwargs['ssl_keyfile'] = conf.ssl_keyfile
@@ -86,7 +77,8 @@ class DataDriver(storage.DataDriverBase):
 
         conn = self.connection
         server_info = conn.server_info()['version']
-        self.server_version = tuple(map(int, server_info.split('.')))
+        version_str = server_info.split('-')[0]
+        self.server_version = tuple(map(int, version_str.split('.')))
 
         if self.server_version < (2, 2):
             raise RuntimeError(_('The mongodb driver requires mongodb>=2.2, '
@@ -142,10 +134,11 @@ class DataDriver(storage.DataDriverBase):
         message_volume = {'free': 0, 'claimed': 0, 'total': 0}
 
         for msg_col in [db.messages for db in self.message_databases]:
-            msg_count_claimed = msg_col.find({'c.id': {'$ne': None}}).count()
+            msg_count_claimed = msg_col.count_documents({'c.id':
+                                                        {'$ne': None}})
             message_volume['claimed'] += msg_count_claimed
 
-            msg_count_total = msg_col.find().count()
+            msg_count_total = msg_col.count_documents({})
             message_volume['total'] += msg_count_total
 
         message_volume['free'] = (message_volume['total'] -
