@@ -23,7 +23,9 @@ Field Mappings:
 
 import datetime
 import time
+import uuid
 
+from bson import binary
 from bson import objectid
 from oslo_log import log as logging
 from oslo_utils import timeutils
@@ -169,28 +171,28 @@ class MessageController(storage.Message):
     def _ensure_indexes(self, collection):
         """Ensures that all indexes are created."""
 
-        collection.ensure_index(TTL_INDEX_FIELDS,
+        collection.create_index(TTL_INDEX_FIELDS,
                                 name='ttl',
                                 expireAfterSeconds=0,
                                 background=True)
 
-        collection.ensure_index(ACTIVE_INDEX_FIELDS,
+        collection.create_index(ACTIVE_INDEX_FIELDS,
                                 name='active',
                                 background=True)
 
-        collection.ensure_index(CLAIMED_INDEX_FIELDS,
+        collection.create_index(CLAIMED_INDEX_FIELDS,
                                 name='claimed',
                                 background=True)
 
-        collection.ensure_index(COUNTING_INDEX_FIELDS,
+        collection.create_index(COUNTING_INDEX_FIELDS,
                                 name='counting',
                                 background=True)
 
-        collection.ensure_index(MARKER_INDEX_FIELDS,
+        collection.create_index(MARKER_INDEX_FIELDS,
                                 name='queue_marker',
                                 background=True)
 
-        collection.ensure_index(TRANSACTION_INDEX_FIELDS,
+        collection.create_index(TRANSACTION_INDEX_FIELDS,
                                 name='transaction',
                                 background=True)
 
@@ -234,7 +236,7 @@ class MessageController(storage.Message):
     def _list(self, queue_name, project=None, marker=None,
               echo=False, client_uuid=None, projection=None,
               include_claimed=False, include_delayed=False,
-              sort=1, limit=None):
+              sort=1, limit=None, count=False):
         """Message document listing helper.
 
         :param queue_name: Name of the queue to list
@@ -261,13 +263,14 @@ class MessageController(storage.Message):
             to list. The results may include fewer messages than the
             requested `limit` if not enough are available. If limit is
             not specified
+        :param count: (Default False) If return the collection's count
 
         :returns: Generator yielding up to `limit` messages.
         """
 
         if sort not in (1, -1):
-            raise ValueError(u'sort must be either 1 (ascending) '
-                             u'or -1 (descending)')
+            raise ValueError('sort must be either 1 (ascending) '
+                             'or -1 (descending)')
 
         now = timeutils.utcnow_ts()
 
@@ -284,6 +287,12 @@ class MessageController(storage.Message):
         }
 
         if not echo:
+            if (client_uuid is not None) and not isinstance(client_uuid,
+                                                            uuid.UUID):
+                client_uuid = uuid.UUID(client_uuid)
+                client_uuid = binary.Binary.from_uuid(client_uuid)
+            elif isinstance(client_uuid, uuid.UUID):
+                client_uuid = binary.Binary.from_uuid(client_uuid)
             query['u'] = {'$ne': client_uuid}
 
         if marker is not None:
@@ -308,12 +317,19 @@ class MessageController(storage.Message):
         cursor = collection.find(query,
                                  projection=projection,
                                  sort=[('k', sort)])
+        ntotal = None
+        if count:
+            ntotal = collection.count_documents(query)
 
         if limit is not None:
             cursor.limit(limit)
+            if count:
+                ntotal = collection.count_documents(query, limit=limit)
 
         # NOTE(flaper87): Suggest the index to use for this query to
         # ensure the most performant one is chosen.
+        if count:
+            return cursor.hint(ACTIVE_INDEX_FIELDS), ntotal
         return cursor.hint(ACTIVE_INDEX_FIELDS)
 
     # ----------------------------------------------------------------------
@@ -348,7 +364,8 @@ class MessageController(storage.Message):
             query['c.e'] = {'$lte': timeutils.utcnow_ts()}
 
         collection = self._collection(queue_name, project)
-        return collection.count(filter=query, hint=COUNTING_INDEX_FIELDS)
+        return collection.count_documents(filter=query,
+                                          hint=COUNTING_INDEX_FIELDS)
 
     def _active(self, queue_name, marker=None, echo=False,
                 client_uuid=None, projection=None, project=None,
@@ -383,8 +400,10 @@ class MessageController(storage.Message):
         msgs = collection.find(query, sort=[('k', 1)], **kwargs).hint(
             CLAIMED_INDEX_FIELDS)
 
+        ntotal = collection.count_documents(query)
         if limit is not None:
             msgs = msgs.limit(limit)
+            ntotal = collection.count_documents(query, limit=limit)
 
         now = timeutils.utcnow_ts()
 
@@ -394,7 +413,7 @@ class MessageController(storage.Message):
 
             return doc
 
-        return utils.HookedCursor(msgs, denormalizer)
+        return utils.HookedCursor(msgs, denormalizer, ntotal=ntotal)
 
     def _unclaim(self, queue_name, claim_id, project=None):
         cid = utils.to_oid(claim_id)
@@ -465,9 +484,9 @@ class MessageController(storage.Message):
                 # NOTE(kgriffs): Since we did not filter by a time window,
                 # the queue should have been found and updated. Perhaps
                 # the queue has been deleted?
-                message = (u'Failed to increment the message '
-                           u'counter for queue %(name)s and '
-                           u'project %(project)s')
+                message = ('Failed to increment the message '
+                           'counter for queue %(name)s and '
+                           'project %(project)s')
                 message %= dict(name=queue_name, project=project)
 
                 LOG.warning(message)
@@ -540,10 +559,13 @@ class MessageController(storage.Message):
             except ValueError:
                 yield iter([])
 
-        messages = self._list(queue_name, project=project, marker=marker,
-                              client_uuid=client_uuid, echo=echo,
-                              include_claimed=include_claimed,
-                              include_delayed=include_delayed, limit=limit)
+        messages, ntotal = self._list(queue_name, project=project,
+                                      marker=marker,
+                                      client_uuid=client_uuid, echo=echo,
+                                      include_claimed=include_claimed,
+                                      include_delayed=include_delayed,
+                                      limit=limit,
+                                      count=True)
 
         marker_id = {}
 
@@ -556,7 +578,7 @@ class MessageController(storage.Message):
 
             return _basic_message(msg, now)
 
-        yield utils.HookedCursor(messages, denormalizer)
+        yield utils.HookedCursor(messages, denormalizer, ntotal=ntotal)
         yield str(marker_id['next'])
 
     @utils.raises_conn_error
@@ -617,11 +639,12 @@ class MessageController(storage.Message):
         # NOTE(flaper87): Should this query
         # be sorted?
         messages = collection.find(query).hint(ID_INDEX_FIELDS)
+        ntotal = collection.count_documents(query)
 
         def denormalizer(msg):
             return _basic_message(msg, now)
 
-        return utils.HookedCursor(messages, denormalizer)
+        return utils.HookedCursor(messages, denormalizer, ntotal=ntotal)
 
     @utils.raises_conn_error
     @utils.retries_on_autoreconnect
@@ -634,11 +657,19 @@ class MessageController(storage.Message):
         if not self._queue_ctrl.exists(queue_name, project):
             raise errors.QueueDoesNotExist(queue_name, project)
 
+        if (client_uuid is not None) and not isinstance(client_uuid,
+                                                        uuid.UUID):
+            client_uuid = uuid.UUID(client_uuid)
+            client_uuid = binary.Binary.from_uuid(client_uuid)
+        elif isinstance(client_uuid, uuid.UUID):
+            client_uuid = binary.Binary.from_uuid(client_uuid)
+
         # NOTE(flaper87): Make sure the counter exists. This method
         # is an upsert.
         self._get_counter(queue_name, project)
         now = timeutils.utcnow_ts()
-        now_dt = datetime.datetime.utcfromtimestamp(now)
+        now_dt = datetime.datetime.fromtimestamp(
+            now, tz=datetime.timezone.utc).replace(tzinfo=None)
         collection = self._collection(queue_name, project)
 
         messages = list(messages)
@@ -776,20 +807,20 @@ class FIFOMessageController(MessageController):
     def _ensure_indexes(self, collection):
         """Ensures that all indexes are created."""
 
-        collection.ensure_index(TTL_INDEX_FIELDS,
+        collection.create_index(TTL_INDEX_FIELDS,
                                 name='ttl',
                                 expireAfterSeconds=0,
                                 background=True)
 
-        collection.ensure_index(ACTIVE_INDEX_FIELDS,
+        collection.create_index(ACTIVE_INDEX_FIELDS,
                                 name='active',
                                 background=True)
 
-        collection.ensure_index(CLAIMED_INDEX_FIELDS,
+        collection.create_index(CLAIMED_INDEX_FIELDS,
                                 name='claimed',
                                 background=True)
 
-        collection.ensure_index(COUNTING_INDEX_FIELDS,
+        collection.create_index(COUNTING_INDEX_FIELDS,
                                 name='counting',
                                 background=True)
 
@@ -800,12 +831,12 @@ class FIFOMessageController(MessageController):
         # to miss a message when there is more than one
         # producer posting messages to the same queue, in
         # parallel.
-        collection.ensure_index(MARKER_INDEX_FIELDS,
+        collection.create_index(MARKER_INDEX_FIELDS,
                                 name='queue_marker',
                                 unique=True,
                                 background=True)
 
-        collection.ensure_index(TRANSACTION_INDEX_FIELDS,
+        collection.create_index(TRANSACTION_INDEX_FIELDS,
                                 name='transaction',
                                 background=True)
 
@@ -824,7 +855,8 @@ class FIFOMessageController(MessageController):
         # is an upsert.
         self._get_counter(queue_name, project)
         now = timeutils.utcnow_ts()
-        now_dt = datetime.datetime.utcfromtimestamp(now)
+        now_dt = datetime.datetime.fromtimestamp(
+            now, tz=datetime.timezone.utc).replace(tzinfo=None)
         collection = self._collection(queue_name, project)
 
         # Set the next basis marker for the first attempt.
@@ -840,6 +872,13 @@ class FIFOMessageController(MessageController):
         # Unique transaction ID to facilitate atomic batch inserts
         transaction = objectid.ObjectId()
 
+        if (client_uuid is not None) and not isinstance(client_uuid,
+                                                        uuid.UUID):
+            client_uuid = uuid.UUID(client_uuid)
+            client_uuid = binary.Binary.from_uuid(client_uuid)
+        elif isinstance(client_uuid, uuid.UUID):
+            client_uuid = binary.Binary.from_uuid(client_uuid)
+
         prepared_messages = []
         for index, message in enumerate(messages):
             msg = {
@@ -878,9 +917,9 @@ class FIFOMessageController(MessageController):
 
                 # Log a message if we retried, for debugging perf issues
                 if attempt != 0:
-                    msgtmpl = _(u'%(attempts)d attempt(s) required to post '
-                                u'%(num_messages)d messages to queue '
-                                u'"%(queue)s" under project %(project)s')
+                    msgtmpl = _('%(attempts)d attempt(s) required to post '
+                                '%(num_messages)d messages to queue '
+                                '"%(queue)s" under project %(project)s')
 
                     LOG.debug(msgtmpl,
                               dict(queue=queue_name,
@@ -923,9 +962,9 @@ class FIFOMessageController(MessageController):
                 #
                 # TODO(kgriffs): Add transaction ID to help match up loglines
                 if attempt == 0:
-                    msgtmpl = _(u'First attempt failed while '
-                                u'adding messages to queue '
-                                u'"%(queue)s" under project %(project)s')
+                    msgtmpl = _('First attempt failed while '
+                                'adding messages to queue '
+                                '"%(queue)s" under project %(project)s')
 
                     LOG.debug(msgtmpl, dict(queue=queue_name, project=project))
 
@@ -937,8 +976,8 @@ class FIFOMessageController(MessageController):
                 # this situation can not happen.
                 elapsed = timeutils.utcnow_ts() - now
                 if elapsed > MAX_RETRY_POST_DURATION:
-                    msgtmpl = (u'Exceeded maximum retry duration for queue '
-                               u'"%(queue)s" under project %(project)s')
+                    msgtmpl = ('Exceeded maximum retry duration for queue '
+                               '"%(queue)s" under project %(project)s')
 
                     LOG.warning(msgtmpl,
                                 dict(queue=queue_name, project=project))
@@ -981,10 +1020,10 @@ class FIFOMessageController(MessageController):
                     next_marker = self._get_counter(
                         queue_name, project)
                 else:
-                    msgtmpl = (u'Detected a stalled message counter '
-                               u'for queue "%(queue)s" under '
-                               u'project %(project)s.'
-                               u'The counter was incremented to %(value)d.')
+                    msgtmpl = ('Detected a stalled message counter '
+                               'for queue "%(queue)s" under '
+                               'project %(project)s.'
+                               'The counter was incremented to %(value)d.')
 
                     LOG.warning(msgtmpl,
                                 dict(queue=queue_name,
@@ -997,8 +1036,8 @@ class FIFOMessageController(MessageController):
                 LOG.exception('Error parsing document')
                 raise
 
-        msgtmpl = (u'Hit maximum number of attempts (%(max)s) for queue '
-                   u'"%(queue)s" under project %(project)s')
+        msgtmpl = ('Hit maximum number of attempts (%(max)s) for queue '
+                   '"%(queue)s" under project %(project)s')
 
         LOG.warning(msgtmpl,
                     dict(max=self.driver.mongodb_conf.max_attempts,
