@@ -31,7 +31,8 @@ from zaqar.storage import errors as storage_errors
 
 # BSON ObjectId gives TZ-aware datetime, so we generate a
 # TZ-aware UNIX epoch for convenience.
-EPOCH = datetime.datetime.utcfromtimestamp(0).replace(tzinfo=tz_util.utc)
+EPOCH = datetime.datetime.fromtimestamp(
+    0, tz=datetime.timezone.utc).replace(tzinfo=tz_util.utc)
 
 # NOTE(cpp-cabrera): the authoritative form of project/queue keys.
 PROJ_QUEUE_KEY = 'p_q'
@@ -87,13 +88,13 @@ def calculate_backoff(attempt, max_attempts, max_sleep, max_jitter=0):
     """
 
     if max_sleep < 0:
-        raise ValueError(u'max_sleep must be >= 0')
+        raise ValueError('max_sleep must be >= 0')
 
     if max_jitter < 0:
-        raise ValueError(u'max_jitter must be >= 0')
+        raise ValueError('max_jitter must be >= 0')
 
     if not (0 <= attempt < max_attempts):
-        raise ValueError(u'attempt value is out of range')
+        raise ValueError('attempt value is out of range')
 
     ratio = attempt / max_attempts
     backoff_sec = ratio * max_sleep
@@ -125,7 +126,7 @@ def oid_ts(oid):
     try:
         return timeutils.delta_seconds(EPOCH, oid.generation_time)
     except AttributeError:
-        raise TypeError(u'Expected ObjectId and got %s' % type(oid))
+        raise TypeError('Expected ObjectId and got %s' % type(oid))
 
 
 def stat_message(message, now):
@@ -133,8 +134,9 @@ def stat_message(message, now):
     msg_id = message['id']
     created = oid_ts(to_oid(msg_id))
     age = now - created
-    created_iso = datetime.datetime.utcfromtimestamp(created).strftime(
-        '%Y-%m-%dT%H:%M:%SZ')
+    created_iso = datetime.datetime.fromtimestamp(
+        created, tz=datetime.timezone.utc).replace(tzinfo=None).strftime(
+            '%Y-%m-%dT%H:%M:%SZ')
     return {
         'id': msg_id,
         'age': int(age),
