@@ -13,6 +13,7 @@
 # limitations under the License.
 
 from oslo_log import log as logging
+from oslo_utils import netutils
 from osprofiler import profiler
 import redis
 import redis.sentinel
@@ -60,12 +61,8 @@ class ConnectionURI(object):
             cred, sep, netloc = netloc.partition('@')
 
         if self.username and not self.password:
-            # NOTE(tkajinam): This is kept for backword compatibility but
-            #                 should be removed after 2025.1
-            LOG.warning('Credential in redis uri does not contain \':\'. '
-                        'Make sure that \':\' is added before password.')
-            self.password = self.username
-            self.username = None
+            raise errors.ConfigurationError(
+                _('Password should be set when username is set'))
 
         query_params = dict(urllib.parse.parse_qsl(query))
 
@@ -96,24 +93,12 @@ class ConnectionURI(object):
             # NOTE(kgriffs): Have to parse list of sentinel hosts ourselves
             # since urllib doesn't support it.
             for each_host in netloc.split(','):
-                if not each_host.endswith(']') and ':' in each_host:
-                    name, sep, port = each_host.rpartition(':')
-                else:
-                    name = each_host
-                    port = None
-
-                if name.startswith('[') and name.endswith(']'):
-                    name = name[1:-1]
-
-                if port:
-                    try:
-                        port = int(port)
-                    except ValueError:
-                        msg = _('The Redis configuration URI contains an '
-                                'invalid port')
-                        raise errors.ConfigurationError(msg)
-                else:
-                    port = SENTINEL_DEFAULT_PORT
+                try:
+                    name, port = netutils.parse_host_port(
+                        each_host, SENTINEL_DEFAULT_PORT)
+                except ValueError:
+                    raise errors.ConfigurationError(
+                        'invalid redis server format %s' % each_host)
 
                 self.sentinels.append((name, port))
 
