@@ -63,9 +63,8 @@ class QueueController(storage.Queue):
     def __init__(self, *args, **kwargs):
         super(QueueController, self).__init__(*args, **kwargs)
         self._client = self.driver.connection
-        self._packer = msgpack.Packer(encoding='utf-8',
-                                      use_bin_type=True).pack
-        self._unpacker = functools.partial(msgpack.unpackb, encoding='utf-8')
+        self._packer = msgpack.Packer(use_bin_type=True).pack
+        self._unpacker = functools.partial(msgpack.unpackb)
 
     @decorators.lazy_property(write=False)
     def _claim_ctrl(self):
