@@ -13,7 +13,7 @@
 
 import logging
 from osprofiler import profiler
-from six.moves import urllib
+import urllib
 
 from keystoneauth1.identity import generic
 from keystoneauth1 import session as keystone_session
@@ -21,20 +21,21 @@ from oslo_log import log as oslo_logging
 import swiftclient
 
 from zaqar.common import decorators
+from zaqar.conf import drivers_message_store_swift
 from zaqar import storage
 from zaqar.storage.swift import controllers
-from zaqar.storage.swift import options
 
 LOG = oslo_logging.getLogger(__name__)
 
 
 class DataDriver(storage.DataDriverBase):
 
-    _DRIVER_OPTIONS = options._config_options()
+    _DRIVER_OPTIONS = [(drivers_message_store_swift.GROUP_NAME,
+                        drivers_message_store_swift.ALL_OPTS)]
 
     def __init__(self, conf, cache, control_driver):
         super(DataDriver, self).__init__(conf, cache, control_driver)
-        self.swift_conf = self.conf[options.MESSAGE_SWIFT_GROUP]
+        self.swift_conf = self.conf[drivers_message_store_swift.GROUP_NAME]
         if not self.conf.debug:
             # Reduce swiftclient logging, in particular to remove 404s
             logging.getLogger("swiftclient").setLevel(logging.WARNING)
@@ -54,8 +55,8 @@ class DataDriver(storage.DataDriverBase):
         try:
             self.connection.get_capabilities()
             return True
-        except Exception as e:
-            LOG.exception(e)
+        except Exception:
+            LOG.exception('Aliveness check failed:')
             return False
 
     @decorators.lazy_property(write=False)
@@ -104,6 +105,7 @@ class _ClientWrapper(object):
 
     def __init__(self, conf):
         self.conf = conf
+        self.endpoint = None
         self.parsed_url = urllib.parse.urlparse(conf.uri)
         self.session = None
 
@@ -118,10 +120,19 @@ class _ClientWrapper(object):
             project_domain_name=self.conf.project_domain_name,
             auth_url=self.conf.auth_url)
         self.session = keystone_session.Session(auth=auth)
+        self.endpoint = self.session.get_endpoint(
+            service_type='object-store',
+            interface=self.conf.interface,
+            region_name=self.conf.region_name
+        )
 
     def __getattr__(self, attr):
         if self.session is None:
             self._init_auth()
+        os_options = {
+            'object_storage_url': self.endpoint
+        }
         client = swiftclient.Connection(session=self.session,
-                                        insecure=self.conf.insecure)
+                                        insecure=self.conf.insecure,
+                                        os_options=os_options)
         return getattr(client, attr)
