@@ -168,8 +168,8 @@ class MessageController(storage.Message):
 
     def first(self, queue, project=None, sort=1):
         if sort not in (1, -1):
-            raise ValueError(u'sort must be either 1 (ascending) '
-                             u'or -1 (descending)')
+            raise ValueError('sort must be either 1 (ascending) '
+                             'or -1 (descending)')
         cursor = self._list(queue, project, limit=1, sort=sort)
         try:
             message = next(next(cursor))
@@ -216,7 +216,7 @@ class MessageController(storage.Message):
 
     def bulk_get(self, queue, message_ids, project=None):
         if not self._queue_ctrl.exists(queue, project):
-            raise StopIteration()
+            return
 
         for id in message_ids:
             try:
@@ -352,8 +352,9 @@ class MessageQueueHandler(object):
                     raise
             else:
                 created = float(headers['x-timestamp'])
-                created_iso = datetime.datetime.utcfromtimestamp(
-                    created).strftime('%Y-%m-%dT%H:%M:%SZ')
+                created_iso = datetime.datetime.fromtimestamp(
+                    created, tz=datetime.timezone.utc).replace(
+                        tzinfo=None).strftime('%Y-%m-%dT%H:%M:%SZ')
                 newest = {
                     'id': obj['name'],
                     'age': now - created,
@@ -442,8 +443,9 @@ class MessageTopicHandler(object):
                     raise
             else:
                 created = float(headers['x-timestamp'])
-                created_iso = datetime.datetime.utcfromtimestamp(
-                    created).strftime('%Y-%m-%dT%H:%M:%SZ')
+                created_iso = datetime.datetime.fromtimestamp(
+                    created, tz=datetime.timezone.utc).replace(
+                        tzinfo=None).strftime('%Y-%m-%dT%H:%M:%SZ')
                 newest = {
                     'id': obj['name'],
                     'age': now - created,
