@@ -16,22 +16,22 @@
 import collections
 import datetime
 import time
+from unittest import mock
 import uuid
 
-import mock
 from oslo_utils import timeutils
 from pymongo import cursor
 import pymongo.errors
-import six
 from testtools import matchers
 
 from zaqar.common import cache as oslo_cache
-from zaqar.common import configs
+from zaqar.conf import default
+from zaqar.conf import drivers_management_store_mongodb
+from zaqar.conf import drivers_message_store_mongodb
 from zaqar import storage
 from zaqar.storage import errors
 from zaqar.storage import mongodb
 from zaqar.storage.mongodb import controllers
-from zaqar.storage.mongodb import options
 from zaqar.storage.mongodb import utils
 from zaqar.storage import pooling
 from zaqar import tests as testing
@@ -51,12 +51,12 @@ class MongodbSetupMixin(object):
             self.driver.connection.drop_database(db)
 
     def _prepare_conf(self):
-        if options.MESSAGE_MONGODB_GROUP in self.conf:
-            self.config(options.MESSAGE_MONGODB_GROUP,
+        if drivers_message_store_mongodb.GROUP_NAME in self.conf:
+            self.config(drivers_message_store_mongodb.GROUP_NAME,
                         database=uuid.uuid4().hex)
 
-        if options.MANAGEMENT_MONGODB_GROUP in self.conf:
-            self.config(options.MANAGEMENT_MONGODB_GROUP,
+        if drivers_management_store_mongodb.GROUP_NAME in self.conf:
+            self.config(drivers_management_store_mongodb.GROUP_NAME,
                         database=uuid.uuid4().hex)
 
 
@@ -67,10 +67,10 @@ class MongodbUtilsTest(MongodbSetupMixin, testing.TestBase):
     def setUp(self):
         super(MongodbUtilsTest, self).setUp()
 
-        self.conf.register_opts(options.MESSAGE_MONGODB_OPTIONS,
-                                group=options.MESSAGE_MONGODB_GROUP)
+        self.conf.register_opts(drivers_message_store_mongodb.ALL_OPTS,
+                                group=drivers_message_store_mongodb.GROUP_NAME)
 
-        self.mongodb_conf = self.conf[options.MESSAGE_MONGODB_GROUP]
+        self.mongodb_conf = self.conf[drivers_message_store_mongodb.GROUP_NAME]
 
         MockDriver = collections.namedtuple('MockDriver', 'mongodb_conf')
 
@@ -152,7 +152,7 @@ class MongodbDriverTest(MongodbSetupMixin, testing.TestBase):
     def setUp(self):
         super(MongodbDriverTest, self).setUp()
 
-        self.conf.register_opts(configs._GENERAL_OPTIONS)
+        self.conf.register_opts(default.ALL_OPTS)
         self.config(unreliable=False)
         oslo_cache.register_config(self.conf)
 
@@ -172,17 +172,37 @@ class MongodbDriverTest(MongodbSetupMixin, testing.TestBase):
 
         with mock.patch('pymongo.MongoClient.server_info') as info:
             info.return_value = {'version': '2.1'}
+            self.assertRaises(RuntimeError, mongodb.DataDriver,
+                              self.conf, cache,
+                              mongodb.ControlDriver(self.conf, cache))
+            info.return_value = {'version': '2.1.0'}
+            self.assertRaises(RuntimeError, mongodb.DataDriver,
+                              self.conf, cache,
+                              mongodb.ControlDriver(self.conf, cache))
+            info.return_value = {'version': '2.1.0-1.0'}
             self.assertRaises(RuntimeError, mongodb.DataDriver,
                               self.conf, cache,
                               mongodb.ControlDriver(self.conf, cache))
 
-            info.return_value = {'version': '2.11'}
+            info.return_value = {'version': '2.2'}
+            mongodb.DataDriver(self.conf, cache,
+                               mongodb.ControlDriver(self.conf, cache))
+            info.return_value = {'version': '2.2.0'}
+            mongodb.DataDriver(self.conf, cache,
+                               mongodb.ControlDriver(self.conf, cache))
+            info.return_value = {'version': '2.2.0-1.0'}
+            mongodb.DataDriver(self.conf, cache,
+                               mongodb.ControlDriver(self.conf, cache))
 
-            try:
-                mongodb.DataDriver(self.conf, cache,
-                                   mongodb.ControlDriver(self.conf, cache))
-            except RuntimeError:
-                self.fail('version match failed')
+            info.return_value = {'version': '2.10'}
+            mongodb.DataDriver(self.conf, cache,
+                               mongodb.ControlDriver(self.conf, cache))
+            info.return_value = {'version': '2.10.0'}
+            mongodb.DataDriver(self.conf, cache,
+                               mongodb.ControlDriver(self.conf, cache))
+            info.return_value = {'version': '2.10.0-1.0'}
+            mongodb.DataDriver(self.conf, cache,
+                               mongodb.ControlDriver(self.conf, cache))
 
     def test_replicaset_or_mongos_needed(self):
         cache = oslo_cache.get_cache(self.conf)
@@ -272,7 +292,7 @@ class MongodbQueueTests(MongodbSetupMixin, base.QueueControllerTest):
     def test_raises_connection_error(self):
 
         with mock.patch.object(cursor.Cursor,
-                               'next' if six.PY2 else '__next__',
+                               '__next__',
                                spec=True) as method:
             error = pymongo.errors.ConnectionFailure()
             method.side_effect = error
@@ -313,10 +333,10 @@ class MongodbMessageTests(MongodbSetupMixin, base.MessageControllerTest):
         seed_marker1 = self.controller._get_counter(queue_name,
                                                     self.project)
         self.assertEqual(0, seed_marker1, 'First marker is 0')
-
+        uuid = '97b64000-2526-11e3-b088-d85c1300734c'
         for i in range(iterations):
-            self.controller.post(queue_name, [{'ttl': 60}],
-                                 'uuid', project=self.project)
+            self.controller.post(queue_name, [{'ttl': 60}], uuid,
+                                 project=self.project)
 
             marker1 = self.controller._get_counter(queue_name,
                                                    self.project)
@@ -507,22 +527,16 @@ class MongodbPoolsTests(base.PoolsControllerTest):
 
     def setUp(self):
         super(MongodbPoolsTests, self).setUp()
-        self.pools_controller.create(self.pool, 100, 'localhost',
-                                     group=self.pool_group, options={})
+        self.uri2 = str(uuid.uuid1())
+        self.flavor2 = str(uuid.uuid1())
+        self.pools_controller.create(self.pool, 100, self.uri2,
+                                     flavor=self.flavor2, options={})
 
     def tearDown(self):
+        # self.pool_ctrl.update(self.pool, flavor="")
+        self.pools_controller.drop_all()
         super(MongodbPoolsTests, self).tearDown()
 
-    # NOTE(gengchc2): remove test_delete_pool_used_by_flavor in Rocky release
-    # and use test_delete_pool_used_by_flavor1 instead for pool_group removal.
-    def test_delete_pool_used_by_flavor(self):
-        self.flavors_controller.create('durable', self.pool_group,
-                                       project=self.project,
-                                       capabilities={})
-
-        with testing.expect(errors.PoolInUseByFlavor):
-            self.pools_controller.delete(self.pool)
-
     # NOTE(gengchc2): Unittest for new flavor configure scenario.
     def test_delete_pool_used_by_flavor1(self):
         self.flavors_controller.create(self.flavor,
@@ -533,16 +547,6 @@ class MongodbPoolsTests(base.PoolsControllerTest):
         with testing.expect(errors.PoolInUseByFlavor):
             self.pools_controller.delete(self.pool1)
 
-    # NOTE(gengchc2): remove test_mismatching_capabilities_fifo in Rocky
-    # release and use test_mismatching_capabilities_fifo1 instead for
-    # pool_group removal.
-    def test_mismatching_capabilities_fifo(self):
-        with testing.expect(errors.PoolCapabilitiesMismatch):
-            self.pools_controller.create(str(uuid.uuid1()),
-                                         100, 'mongodb.fifo://localhost',
-                                         group=self.pool_group,
-                                         options={})
-
     # NOTE(gengchc2): Unittest for new flavor configure scenario.
     def test_mismatching_capabilities_fifo1(self):
         with testing.expect(errors.PoolCapabilitiesMismatch):
@@ -551,17 +555,6 @@ class MongodbPoolsTests(base.PoolsControllerTest):
                                          flavor=self.flavor,
                                          options={})
 
-    # NOTE(gengchc2): remove test_mismatching_capabilities in Rocky release
-    #  and use test_mismatching_capabilities1 instead for pool_group removal.
-    def test_mismatching_capabilities(self):
-        # NOTE(gengchc2): This test is used for testing mismatchming
-        # capabilities in pool with group
-        with testing.expect(errors.PoolCapabilitiesMismatch):
-            self.pools_controller.create(str(uuid.uuid1()),
-                                         100, 'redis://localhost',
-                                         group=self.pool_group,
-                                         options={})
-
     def test_mismatching_capabilities1(self):
         # NOTE(gengchc2): This test is used for testing mismatchming
         # capabilities in pool with flavor
@@ -571,21 +564,12 @@ class MongodbPoolsTests(base.PoolsControllerTest):
                                          flavor=self.flavor,
                                          options={})
 
-    # NOTE(gengchc2): remove test_duplicate_uri in Rocky release and
-    #  use test_duplicate_uri1 instead for pool_group removal.
-    def test_duplicate_uri(self):
-        with testing.expect(errors.PoolAlreadyExists):
-            # The url 'localhost' is used in setUp(). So reusing the uri
-            # 'localhost' here will raise PoolAlreadyExists.
-            self.pools_controller.create(str(uuid.uuid1()), 100, 'localhost',
-                                         group=str(uuid.uuid1()), options={})
-
     # NOTE(gengchc2): Unittest for new flavor configure scenario.
     def test_duplicate_uri1(self):
         with testing.expect(errors.PoolAlreadyExists):
             # The url 'localhost' is used in setUp(). So reusing the uri
             # 'localhost' here will raise PoolAlreadyExists.
-            self.pools_controller.create(str(uuid.uuid1()), 100, 'localhost',
+            self.pools_controller.create(str(uuid.uuid1()), 100, self.uri,
                                          flavor=str(uuid.uuid1()), options={})
 
 
@@ -632,20 +616,6 @@ class PooledClaimsTests(base.ClaimControllerTest):
         self.skip("Fix sqlalchemy driver")
 
 
-# NOTE(gengchc2): remove MongodbFlavorsTest in Rocky release and
-# use MongodbFlavorsTest1 instead for pool_group removal.
-@testing.requires_mongodb
-class MongodbFlavorsTest(base.FlavorsControllerTest):
-    driver_class = mongodb.ControlDriver
-    controller_class = controllers.FlavorsController
-    control_driver_class = mongodb.ControlDriver
-    config_file = 'wsgi_mongodb.conf'
-
-    def setUp(self):
-        super(MongodbFlavorsTest, self).setUp()
-        self.addCleanup(self.controller.drop_all)
-
-
 # NOTE(gengchc2): Unittest for new flavor configure scenario.
 @testing.requires_mongodb
 class MongodbFlavorsTest1(base.FlavorsControllerTest1):
