@@ -224,8 +224,8 @@ class QueueLifecycleBaseTest(base.V2Base):
         self.protocol.onMessage(req, False)
 
     def test_non_ascii_name(self):
-        test_params = ((u'/queues/non-ascii-n\u0153me', 'utf-8'),
-                       (u'/queues/non-ascii-n\xc4me', 'iso8859-1'))
+        test_params = (('/queues/non-ascii-n\u0153me', 'utf-8'),
+                       ('/queues/non-ascii-n\xc4me', 'iso8859-1'))
 
         headers = {
             'Client-ID': uuidutils.generate_uuid(),
