@@ -23,7 +23,7 @@ from oslo_utils import uuidutils
 from zaqar.tests.unit.transport.wsgi import base
 
 
-class TestAuth(base.V1_1Base):
+class TestAuth(base.V2Base):
 
     config_file = 'keystone_auth.conf'
 
