@@ -13,7 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import asyncio
 import datetime
+import email
 import io
 import sys
 
@@ -22,21 +24,8 @@ import msgpack
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-import pytz
 import txaio
 
-try:
-    import asyncio
-except ImportError:
-    import trollius as asyncio
-
-try:
-    import mimetools
-    Message = mimetools.Message
-except ImportError:
-    import email
-    Message = email.message_from_binary_file
-
 from zaqar.common import consts
 
 
@@ -164,7 +153,7 @@ class MessagingProtocol(websocket.WebSocketServerProtocol):
         self._auth_app = None
         expire = env['keystone.token_info']['token']['expires_at']
         expire_time = timeutils.parse_isotime(expire)
-        now = datetime.datetime.now(tz=pytz.UTC)
+        now = datetime.datetime.now(tz=datetime.timezone.utc)
         delta = (expire_time - now).total_seconds()
         if self._deauth_handle is not None:
             self._deauth_handle.cancel()
@@ -176,7 +165,7 @@ class MessagingProtocol(websocket.WebSocketServerProtocol):
     def _deauthenticate(self):
         self._authentified = False
         self._auth_env = None
-        self.sendClose(4003, u'Authentication expired.')
+        self.sendClose(4003, 'Authentication expired.')
 
     def _auth_response(self, status, message):
         code = int(status.split()[0])
@@ -253,7 +242,8 @@ class NotificationProtocol(asyncio.Protocol):
 
         if self._state == 'HEADERS' and b'\r\n\r\n' in self._data:
             headers, self._data = self._data.split(b'\r\n\r\n', 1)
-            headers = Message(io.BytesIO(headers))
+            headers = email.message_from_binary_file(io.BytesIO(headers))
+
             # try both cases of content-length for backwards compatibility
             length = headers.get(b'content-length',
                                  headers.get('Content-Length'))
