@@ -13,13 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from distutils import version as d_version
 import falcon
-import six
 import socket
 from wsgiref import simple_server
 
 from oslo_log import log as logging
+from oslo_middleware import request_id
 from oslo_utils import netutils
 
 from zaqar.common import decorators
@@ -33,7 +32,6 @@ from zaqar.transport.middleware import auth
 from zaqar.transport.middleware import cors
 from zaqar.transport.middleware import profile
 from zaqar.transport import validation
-from zaqar.transport.wsgi import v1_0
 from zaqar.transport.wsgi import v1_1
 from zaqar.transport.wsgi import v2_0
 from zaqar.transport.wsgi import version
@@ -100,14 +98,16 @@ class Driver(transport.DriverBase):
             self._validate_queue_identification,
 
             # NOTE(kgriffs): Depends on project_id being extracted, above
-            self._validate_topic_identification
+            self._validate_topic_identification,
+
+            # NOTE(wanghao): verify the extra specs if it is existing
+            helpers.verify_extra_spec
         ]
 
     def _init_routes(self):
         """Initialize hooks and URI routes to resources."""
 
         catalog = [
-            ('/v1', v1_0.public_endpoints(self, self._conf)),
             ('/v1.1', v1_1.public_endpoints(self, self._conf)),
             ('/v2', v2_0.public_endpoints(self, self._conf)),
             ('/', [('', version.Resource())])
@@ -115,21 +115,12 @@ class Driver(transport.DriverBase):
 
         if self._conf.admin_mode:
             catalog.extend([
-                ('/v1', v1_0.private_endpoints(self, self._conf)),
                 ('/v1.1', v1_1.private_endpoints(self, self._conf)),
                 ('/v2', v2_0.private_endpoints(self, self._conf)),
             ])
 
-        # NOTE(wanghao): Since hook feature has removed after 1.0.0, using
-        # middleware instead of it, but for the compatibility with old version,
-        # we support them both now. Hook way can be removed after falcon
-        # version must be bigger than 1.0.0 in requirements.
-        if (d_version.LooseVersion(falcon.__version__) >=
-                d_version.LooseVersion("1.0.0")):
-            middleware = [FuncMiddleware(hook) for hook in self.before_hooks]
-            self.app = falcon.API(middleware=middleware)
-        else:
-            self.app = falcon.API(before=self.before_hooks)
+        middleware = [FuncMiddleware(hook) for hook in self.before_hooks]
+        self.app = falcon.App(middleware=middleware)
 
         # Set options to keep behavior compatible to pre-2.0.0 falcon
         self.app.req_options.auto_parse_qs_csv = True
@@ -156,7 +147,9 @@ class Driver(transport.DriverBase):
             strategy = auth.strategy(self._conf.auth_strategy)
             auth_app = strategy.install(self.app, self._conf)
 
-        self.app = auth.SignedHeadersAuth(self.app, auth_app)
+        self.app = auth.SignedAndExtraSpecHeadersAuth(self.app, auth_app)
+
+        self.app = request_id.RequestId(self.app)
 
         # NOTE(wangxiyuan): Install CORS, this middleware should be called
         # before Keystone auth.
@@ -164,12 +157,13 @@ class Driver(transport.DriverBase):
 
         acl.setup_policy(self._conf)
 
-    def _error_handler(self, exc, request, response, params):
+    def _error_handler(self, request, response, exc, params):
         if isinstance(exc, falcon.HTTPError):
             raise
         LOG.exception('Internal server error')
-        raise falcon.HTTPInternalServerError('Internal server error',
-                                             six.text_type(exc))
+        raise falcon.HTTPInternalServerError(
+            title='Internal server error',
+            description=str(exc))
 
     def _get_server_cls(self, host):
         """Return an appropriate WSGI server class base on provided host
@@ -186,7 +180,7 @@ class Driver(transport.DriverBase):
     def listen(self):
         """Self-host using 'bind' and 'port' from the WSGI config group."""
 
-        msgtmpl = _(u'Serving on host %(bind)s:%(port)s')
+        msgtmpl = _('Serving on host %(bind)s:%(port)s')
         LOG.info(msgtmpl,
                  {'bind': self._wsgi_conf.bind, 'port': self._wsgi_conf.port})
         server_cls = self._get_server_cls(self._wsgi_conf.bind)
